@@ -2,7 +2,7 @@
 # coding: utf-8
 from typing import Tuple
 
-from web3 import Web3
+from eth_account import Account
 
 from . import Config, Bolors
 from .libeb import MiliDoS
@@ -10,7 +10,7 @@ from .libeb import MiliDoS
 
 class ContractTool(MiliDoS):
     classes = [
-        "Genesis", "Mine", "PriceOracle", "USDT", "Currency"
+        "Genesis", "Mine", "Currency"
     ]
 
     def __init__(self, netconfig: Config, root_path, deploy_list: dict, wallet_addresses: list):
@@ -33,38 +33,13 @@ class ContractTool(MiliDoS):
 
     def AuthIndex(self, w_index: int) -> "ContractTool":
         (a, c) = self.auth(w_index)
-        localAcc = Web3.eth.account.privateKeyToAccount(c)
-        self.w3.eth.account = localAcc
-        is_address = self.w3.isAddress(localAcc.address)
-        self.accountAddr = localAcc.address
-        print(f"You are now using {localAcc.address} and it is a {'valid key' if is_address else 'invalid key'}")
+        localAc = Account.from_key(c)
+        self.w3.eth.account = localAc
+        is_address = self.w3.isAddress(localAc.address)
+        self.accountAddr = localAc.address
+        print(f"You are now using {localAc.address} and it is a {'valid key' if is_address else 'invalid key'}")
         return self
 
-    def DistributeCoins(self, from_account_index: int, loops: int, exclude: list = []) -> None:
-        ind = 0
-        skip = exclude
-        while ind < loops:
-            if skip.index(ind) > 0:
-                continue
-            self.AuthIndex(from_account_index).Transfer(ind, 0.1)
-            ind += 1
-
-    def Transfer(self, w_index: int, amount: float, gwei: int = 50) -> str:
-        tx = self.w3.eth.buildTransaction(
-            {
-                'to': self.referrer(w_index),
-                # 'chainId': self.w3.eth.chainId,
-                'gas': 2000000,
-                'gasPrice': self.w3.toWei(gwei, 'gwei'),
-                'nonce': self.w3.eth.getTransactionCount(self.w3.eth.account, block_identifier='pending'),
-                'value': self.w3.toWei(amount, "ether")
-            })
-        signed_txn = self.w3.eth.account.sign_transaction(tx)
-        txhash = self.w3.eth.sendRawTransaction(signed_txn.rawTransaction)
-        hashTxStr = self.w3.toHex(txhash)
-        print(f"✅ {Bolors.OK}{hashTxStr}{Bolors.RESET}")
-        return hashTxStr
-
     def ClassList(self, setup_list: list) -> "ContractTool":
         self.classes = setup_list
         return self
@@ -180,3 +155,41 @@ class ContractTool(MiliDoS):
             return self.getAddr("USDC")
         else:
             raise ValueError("not USDC contract address is found")
+
+    """
+    
+    This is the ETH transfer functions
+    """
+
+    def DistributeCoins(self, from_account_index: int, loops: int, exclude: list, gas: int, price: int) -> None:
+        ind = 0
+        # self.AuthIndex(from_account_index)
+        while ind < loops:
+            if ind in exclude:
+                ind += 1
+                continue
+            if from_account_index == ind:
+                ind += 1
+                continue
+            self.Transfer(ind, 0.1, gas, price)
+            ind += 1
+
+    def Transfer(self, w_index: int, amount: float, gas: int = 2000000, price: int = 500000000) -> str:
+        tx = {
+            'to': self.referrer(w_index),
+            'chainId': self.w3.eth.chainId,
+            'gas': gas,
+            'gasPrice': price,
+            'nonce': self.w3.eth.getTransactionCount(self.w3.eth.account.address),
+            'value': self.w3.toWei(amount, "ether")
+        }
+        # (a, p) = self.auth(w_index)
+        # print(f"private key get {p}")
+        signed_txn = self.w3.eth.account.sign_transaction(tx)
+        print(f"🚸 Before transaction sending data\n{tx}")
+        tx_hash = self.w3.eth.sendRawTransaction(signed_txn.rawTransaction)
+        hash_tx_str = self.w3.toHex(tx_hash)
+        print(f"☕️ Waiting for the block confirmation now ...")
+        self.w3.eth.waitForTransactionReceipt(tx_hash)
+        print(f"✅ {Bolors.OK}{hash_tx_str}{Bolors.RESET}")
+        return hash_tx_str
